import { useState } from 'react';
import { useLocation } from 'wouter';
import { useTranslation } from 'react-i18next';
import { useForm } from 'react-hook-form';
import { zodResolver } from '@hookform/resolvers/zod';
import { z } from 'zod';
import { useQuery, useMutation } from '@tanstack/react-query';
import { Button } from '@/components/ui/button';
import { Input } from '@/components/ui/input';
import { Card, CardContent, CardHeader, CardTitle } from '@/components/ui/card';
import { Form, FormControl, FormField, FormItem, FormLabel, FormMessage } from '@/components/ui/form';
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from '@/components/ui/select';
import { ArrowLeft, Smartphone, Phone, DollarSign, Send, Loader2, Info } from 'lucide-react';
import { useAuth } from '@/contexts/AuthContext';
import { useToast } from '@/hooks/use-toast';
import { apiRequest, queryClient } from '@/lib/queryClient';
import { Logo } from '@/components/Logo';
import { OfficialPayPalButton } from '@/components/OfficialPayPalButton';
import { TopUpSummary } from '@/components/TopUpSummary';
import { calculateTotalWithFees } from '@/components/PaymentSummary';
import { generateTransactionReceipt } from '@/utils/pdfGenerator';


// Schema will use translation keys in component
const topupSchema = z.object({
  countryCode: z.string().min(2),
  operatorId: z.string().min(1),
  recipientPhone: z.string().min(1).refine((phone) => {
    const cleanPhone = phone.replace(/[^0-9]/g, '');
    return /^\d{8,15}$/.test(cleanPhone);
  }),
  amount: z.string().min(1).refine((val) => {
    const num = parseFloat(val);
    return !isNaN(num) && num > 0;
  }),
});

type TopupFormData = z.infer<typeof topupSchema>;

export default function SendTopUp() {
  const [, setLocation] = useLocation();
  const { t } = useTranslation();
  const { user } = useAuth();
  const { toast } = useToast();
  const [step, setStep] = useState(1);
  const [selectedCountry, setSelectedCountry] = useState<any>(null);
  const [selectedOperator, setSelectedOperator] = useState<any>(null);

  const form = useForm<TopupFormData>({
    resolver: zodResolver(topupSchema),
    defaultValues: {
      countryCode: '',
      operatorId: '',
      recipientPhone: '',
      amount: '',
    },
  });

  const { data: countries, isLoading: countriesLoading, error: countriesError } = useQuery<{ countries: any[] }>({
    queryKey: ['/api/topup/countries'],
    enabled: !!user,
  });

  const countryCode = form.watch('countryCode');
  const operatorId = form.watch('operatorId');
  const amount = form.watch('amount');
  
  const { data: operators, isLoading: operatorsLoading } = useQuery<{ operators: any[] }>({
    queryKey: ['/api/topup/operators', countryCode],
    queryFn: async () => {
      if (!countryCode) return { operators: [] };
      const response = await apiRequest('GET', `/api/topup/operators/${countryCode}`);
      return response.json();
    },
    enabled: !!countryCode,
  });

  const { data: destinationAmount, isLoading: destinationLoading } = useQuery<{ destinationAmount: number; localCurrency: string; exchangeRate: number; fee: number }>({
    queryKey: ['/api/topup/destination-amount', operatorId, amount],
    queryFn: async () => {
      if (!operatorId || !amount) return null;
      const response = await apiRequest('POST', '/api/topup/destination-amount', {
        operatorId,
        amount: parseFloat(amount)
      });
      return response.json();
    },
    enabled: !!operatorId && !!amount && parseFloat(amount) > 0,
  });

  const { data: serviceFees } = useQuery<{ serviceFees: any[] }>({
    queryKey: ['/api/admin/service-fees'],
    enabled: !!user,
  });

  const sendTopupMutation = useMutation({
    mutationFn: async (data: any) => {
      const response = await apiRequest('POST', '/api/topup/send', data);
      return response.json();
    },
    onSuccess: (response: any) => {
      queryClient.invalidateQueries({ queryKey: ['/api/transactions'] });
      queryClient.invalidateQueries({ queryKey: ['/api/auth/login'] }); // Refresh user balance
      
      let successMessage = t('topup.successMessage', { 
        amount: form.watch('amount'), 
        phone: form.watch('recipientPhone'), 
        method: response.paymentMethod || 'PayPal' 
      });
      
      // Add reward information if any were earned
      if (response.rewards) {
        const rewards = response.rewards;
        const rewardMessages = [];
        
        if (rewards.promotionsApplied > 0) {
          rewardMessages.push(t('topup.promotionsApplied', { 
            count: rewards.promotionsApplied, 
            discount: rewards.totalDiscount.toFixed(2) 
          }));
        }
        
        if (rewards.loyaltyPointsEarned > 0) {
          rewardMessages.push(t('topup.loyaltyPointsEarned', { points: rewards.loyaltyPointsEarned }));
        }
        
        if (rewards.referralBonusProcessed) {
          rewardMessages.push(t('topup.referralBonusProcessed'));
        }
        
        if (rewardMessages.length > 0) {
          successMessage += `. ${t('topup.rewards')}: ${rewardMessages.join(', ')}`;
        }
      }
      
      toast({
        title: t('topup.topupSentSuccess'),
        description: successMessage,
      });
      
      // Auto-generate and download PDF receipt
      const transactionData = {
        id: response.transaction?.id || Date.now(),
        amount: form.watch('amount'),
        recipientNumber: form.watch('recipientPhone'),
        operatorName: selectedOperator?.name || '',
        countryCode: form.watch('countryCode'),
        status: 'completed',
        description: `TopUp to ${selectedOperator?.name || 'operator'}`,
        reloadlyTransactionId: response.transaction?.reloadlyTransactionId || undefined,
        paypalOrderId: response.transaction?.paypalOrderId || undefined,
        createdAt: new Date().toISOString(),
        metadata: response.rewards || {},
        userInfo: {
          firstName: user?.firstName || '',
          lastName: user?.lastName || '',
          email: user?.email || '',
        }
      };
      
      generateTransactionReceipt(transactionData);
      
      setLocation('/history');
    },
    onError: (error: any) => {
      console.error('TopUp error:', error);
      let errorMessage = t('topup.generalError');
      
      if (error.message) {
        if (error.message.includes('Insufficient wallet balance')) {
          errorMessage = t('topup.insufficientBalance');
        } else if (error.message.includes('Demo: Simulated')) {
          errorMessage = t('topup.testSystemError');
        } else if (error.message.includes('Reloadly')) {
          if (error.message.includes('phone number is not valid')) {
            errorMessage = t('topup.invalidPhoneReloadly');
          } else {
            errorMessage = t('topup.systemIssue');
          }
        } else if (error.message.includes('Failed to send top-up')) {
          errorMessage = t('topup.sendFailure');
        } else if (error.message.includes('phone number is not valid')) {
          errorMessage = t('topup.invalidPhoneFormat');
        } else {
          errorMessage = error.message;
        }
      }
      
      toast({
        title: t('topup.topupError'),
        description: errorMessage,
        variant: 'destructive',
      });
    },
  });

  const onSubmit = async (data: TopupFormData) => {
    const amount = parseFloat(data.amount);
    const walletBalance = parseFloat(user?.walletBalance || '0');
    
    if (amount > walletBalance) {
      toast({
        title: t('topup.insufficientFunds'),
        description: t('topup.insufficientFundsMessage'),
        variant: 'destructive',
      });
      return;
    }

    await sendTopupMutation.mutateAsync({
      operatorId: data.operatorId,
      amount: data.amount,
      recipientPhone: data.recipientPhone,
      countryCode: data.countryCode,
      operatorName: selectedOperator?.name || 'Unknown',
    });
  };

  const handleCountrySelect = (countryCode: string) => {
    const country = countries?.countries.find(c => c.isoName === countryCode);
    setSelectedCountry(country);
    form.setValue('countryCode', countryCode);
    form.setValue('operatorId', '');
    setSelectedOperator(null);
  };

  const handleOperatorSelect = (operatorId: string) => {
    const operator = operators?.operators.find(o => o.id.toString() === operatorId);
    setSelectedOperator(operator);
    form.setValue('operatorId', operatorId);
  };

  return (
    <div className="min-h-screen bg-gray-50">
      {/* Header */}
      <header className="bg-[hsl(184,100%,14%)] text-white sticky top-0 z-40">
        <div className="px-4 py-3">
          <div className="flex items-center space-x-4">
            <Button
              variant="ghost"
              size="sm"
              onClick={() => setLocation('/dashboard')}
              className="text-white hover:bg-white/10 p-2"
            >
              <ArrowLeft className="w-5 h-5" />
            </Button>
            <div className="w-8 h-8 rounded-lg bg-white flex items-center justify-center mr-3">
              <Logo size="sm" />
            </div>
            <div>
              <h1 className="text-lg font-bold">{t('topup.sendTopup')}</h1>
              <p className="text-xs text-gray-300">{t('topup.sendMoney')}</p>
            </div>
          </div>
        </div>
      </header>

      <main className="p-4 pb-32">
        <Form {...form}>
          <form onSubmit={form.handleSubmit(onSubmit)} className="space-y-6">
            {/* Step 1: Country Selection */}
            <Card>
              <CardHeader>
                <CardTitle className="flex items-center space-x-2">
                  <span className="w-6 h-6 rounded-full bg-[hsl(74,100%,84%)] text-[hsl(184,100%,14%)] text-sm font-bold flex items-center justify-center">
                    1
                  </span>
                  <span>{t('topup.selectCountry')}</span>
                </CardTitle>
              </CardHeader>
              <CardContent>
                <FormField
                  control={form.control}
                  name="countryCode"
                  render={({ field }) => (
                    <FormItem>
                      <FormLabel>{t('topup.country')}</FormLabel>
                      {countriesError ? (
                        <div className="p-4 border border-red-200 rounded-lg bg-red-50">
                          <p className="text-red-600 text-sm">
                            Failed to load countries. Please check your internet connection and try again.
                          </p>
                        </div>
                      ) : (
                        <Select onValueChange={handleCountrySelect}>
                          <FormControl>
                            <SelectTrigger>
                              <SelectValue placeholder={t('topup.selectCountryPlaceholder')} />
                            </SelectTrigger>
                          </FormControl>
                          <SelectContent className="max-h-[300px] overflow-auto">
                            {countries && countries.countries && countries.countries.length > 0 ? (
                              countries.countries.map((country) => (
                                <SelectItem 
                                  key={country.isoName} 
                                  value={country.isoName}
                                  className="py-3 cursor-pointer hover:bg-gray-50"
                                >
                                  <div className="flex items-center space-x-3 w-full">
                                    <img 
                                      src={country.flagUrl || `https://flagcdn.com/w40/${country.isoName.toLowerCase()}.png`}
                                      alt={`${country.name} flag`}
                                      className="w-8 h-6 rounded-sm object-cover border border-gray-200 flex-shrink-0"
                                      onError={(e) => {
                                        e.currentTarget.src = 'data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="32" height="24" fill="gray"><rect width="32" height="24" fill="%23f3f4f6"/></svg>';
                                      }}
                                    />
                                    <div className="flex-1 min-w-0">
                                      <span className="font-medium text-gray-900">{country.name}</span>
                                      <div className="text-sm text-gray-500">
                                        {country.currencyCode} • {country.isoName}
                                      </div>
                                    </div>
                                  </div>
                                </SelectItem>
                              ))
                            ) : (
                              <SelectItem value="no-countries" disabled>
                                <div className="text-center py-2 text-gray-500">
                                  No countries available - Check API connection
                                </div>
                              </SelectItem>
                            )}
                          </SelectContent>
                        </Select>
                      )}
                      <FormMessage />
                    </FormItem>
                  )}
                />
              </CardContent>
            </Card>

            {/* Step 2: Operator Selection */}
            {form.watch('countryCode') && (
              <Card>
                <CardHeader>
                  <CardTitle className="flex items-center space-x-2">
                    <span className="w-6 h-6 rounded-full bg-[hsl(74,100%,84%)] text-[hsl(184,100%,14%)] text-sm font-bold flex items-center justify-center">
                      2
                    </span>
                    <span>{t('topup.selectOperator')}</span>
                  </CardTitle>
                </CardHeader>
                <CardContent>
                  <FormField
                    control={form.control}
                    name="operatorId"
                    render={({ field }) => (
                      <FormItem>
                        <FormLabel>{t('topup.operator')}</FormLabel>
                        <Select onValueChange={handleOperatorSelect}>
                          <FormControl>
                            <SelectTrigger>
                              <SelectValue placeholder={t('topup.selectOperatorPlaceholder')} />
                            </SelectTrigger>
                          </FormControl>
                          <SelectContent className="max-h-[300px] overflow-auto">
                            {operators && operators.operators && operators.operators.length > 0 ? 
                              operators.operators.map((operator) => (
                                <SelectItem 
                                  key={operator.id} 
                                  value={operator.id.toString()}
                                  className="py-3 cursor-pointer hover:bg-gray-50"
                                >
                                  <div className="flex items-center space-x-3 w-full">
                                    <div className="w-8 h-8 rounded bg-gray-100 flex items-center justify-center flex-shrink-0">
                                      {operator.logoUrls && operator.logoUrls.length > 0 ? (
                                        <img 
                                          src={operator.logoUrls[0]} 
                                          alt={operator.name}
                                          className="w-6 h-6 rounded object-contain"
                                          onError={(e) => {
                                            e.currentTarget.style.display = 'none';
                                          }}
                                        />
                                      ) : (
                                        <div className="w-4 h-4 bg-gray-300 rounded"></div>
                                      )}
                                    </div>
                                    <div className="flex-1 min-w-0">
                                      <div className="font-medium text-gray-900 truncate">{operator.name}</div>
                                      <div className="text-sm text-gray-500">
                                        {operator.denominationType === 'FIXED' ? 
                                          `Fixed amounts: $${operator.minAmount} - $${operator.maxAmount}` :
                                          `Range: $${operator.minAmount} - $${operator.maxAmount}`
                                        }
                                      </div>
                                    </div>
                                  </div>
                                </SelectItem>
                              )) : (
                              <SelectItem value="no-operators" disabled>
                                <div className="text-center py-2 text-gray-500">
                                  No operators available for this country
                                </div>
                              </SelectItem>
                            )}
                          </SelectContent>
                        </Select>
                        <FormMessage />
                      </FormItem>
                    )}
                  />
                </CardContent>
              </Card>
            )}

            {/* Step 3: Recipient Details */}
            {form.watch('operatorId') && (
              <Card>
                <CardHeader>
                  <CardTitle className="flex items-center space-x-2">
                    <span className="w-6 h-6 rounded-full bg-[hsl(74,100%,84%)] text-[hsl(184,100%,14%)] text-sm font-bold flex items-center justify-center">
                      3
                    </span>
                    <span>{t('topup.recipientDetails')}</span>
                  </CardTitle>
                </CardHeader>
                <CardContent className="space-y-4">
                  <FormField
                    control={form.control}
                    name="recipientPhone"
                    render={({ field }) => (
                      <FormItem>
                        <FormLabel>{t('topup.phoneNumber')}</FormLabel>
                        <FormControl>
                          <div className="relative">
                            <Phone className="absolute left-3 top-1/2 transform -translate-y-1/2 text-gray-400 w-5 h-5" />
                            <Input
                              {...field}
                              placeholder={
                                form.watch('countryCode') === 'HT' 
                                  ? "31317776 (8 chif, san +509)"
                                  : t('topup.phoneNumberPlaceholder')
                              }
                              className="pl-10"
                            />
                          </div>
                        </FormControl>
                        {form.watch('countryCode') === 'HT' && (
                          <div className="mt-2 p-2 bg-blue-50 border border-blue-200 rounded text-sm text-blue-700">
                            <strong>Egzanp pou Haïti:</strong> 31317776<br/>
                            <span className="text-xs">Antre sèlman 8 chif nan nimewo telefòn lan (san +509)</span>
                          </div>
                        )}
                        <FormMessage />
                      </FormItem>
                    )}
                  />

                  <FormField
                    control={form.control}
                    name="amount"
                    render={({ field }) => (
                      <FormItem>
                        <FormLabel>{t('topup.amount')}</FormLabel>
                        <FormControl>
                          <div className="relative">
                            <DollarSign className="absolute left-3 top-1/2 transform -translate-y-1/2 text-gray-400 w-5 h-5" />
                            <Input
                              {...field}
                              type="number"
                              min="1"
                              step="0.01"
                              placeholder="0.00"
                              className="pl-10"
                            />
                          </div>
                        </FormControl>
                        <FormMessage />
                      </FormItem>
                    )}
                  />

                  {/* TopUp Summary */}
                  {amount && parseFloat(amount) > 0 && (
                    <TopUpSummary
                      amount={amount}
                      destinationAmount={destinationAmount?.destinationAmount}
                      localCurrency={destinationAmount?.localCurrency}
                      exchangeRate={destinationAmount?.exchangeRate}
                      serviceFees={serviceFees?.serviceFees || []}
                      recipientPhone={form.watch('recipientPhone')}
                      operatorName={selectedOperator?.name}
                      countryName={selectedCountry?.name}
                    />
                  )}

                  {destinationLoading && amount && operatorId && (
                    <div className="bg-blue-50 border border-blue-200 p-4 rounded-lg">
                      <div className="flex items-center space-x-2">
                        <Loader2 className="w-4 h-4 animate-spin text-blue-600" />
                        <span className="text-blue-700">Calculating destination amount...</span>
                      </div>
                    </div>
                  )}
                </CardContent>
              </Card>
            )}

            {/* Payment Methods */}
            {form.watch('amount') && (
              <Card>
                <CardContent className="p-6">
                  <div className="space-y-4">
                    <h4 className="font-semibold text-blue-900 mb-3">{t('summary.choosePaymentMethod')}</h4>
                    
                    {/* Wallet Payment Option */}
                    {user?.walletBalance && parseFloat(user.walletBalance) >= calculateTotalWithFees(form.watch('amount'), 'topup', serviceFees?.serviceFees) ? (
                      <div className="space-y-3">
                        <Button
                          type="button"
                          className="w-full bg-green-600 hover:bg-green-700 text-white py-3"
                          disabled={sendTopupMutation.isPending}
                          onClick={() => {
                            const topupData = {
                              operatorId: form.watch('operatorId'),
                              amount: form.watch('amount'),
                              recipientPhone: form.watch('recipientPhone'),
                              countryCode: form.watch('countryCode'),
                              operatorName: selectedOperator?.name || 'Unknown',
                              useWallet: true
                            };
                            sendTopupMutation.mutate(topupData);
                          }}
                        >
                          {sendTopupMutation.isPending ? (
                            <>
                              <Loader2 className="w-4 h-4 mr-2 animate-spin" />
                              Sending topup...
                            </>
                          ) : (
                            <>
                              <DollarSign className="w-4 h-4 mr-2" />
                              {t('summary.payWithWallet')} (${user.walletBalance})
                            </>
                          )}
                        </Button>
                        
                        <div className="text-center">
                          <div className="relative">
                            <div className="absolute inset-0 flex items-center">
                              <div className="w-full border-t border-gray-300" />
                            </div>
                            <div className="relative flex justify-center text-sm">
                              <span className="px-2 bg-blue-50 text-gray-500">{t('summary.or')}</span>
                            </div>
                          </div>
                        </div>
                      </div>
                    ) : (
                      <div className="bg-orange-50 border border-orange-200 p-3 rounded-lg mb-3">
                        <div className="flex items-center space-x-2">
                          <Info className="w-4 h-4 text-orange-600" />
                          <span className="text-orange-700 text-sm">
                            Your wallet doesn't have enough funds. You need ${calculateTotalWithFees(form.watch('amount'), 'topup', serviceFees?.serviceFees).toFixed(2)} but you have ${user?.walletBalance || '0.00'}
                          </span>
                        </div>
                      </div>
                    )}
                    
                    {/* PayPal Payment Option */}
                    <div className="space-y-2">
                      <p className="text-sm text-gray-600 text-center">{t('summary.payWithPayPal')}</p>
                      <div className="min-h-[80px] flex items-center justify-center">
                        <OfficialPayPalButton
                          amount={calculateTotalWithFees(form.watch('amount'), 'topup', serviceFees?.serviceFees).toFixed(2)}
                          currency="USD"
                          onSuccess={(details: any) => {
                            console.log('PayPal payment successful for topup:', details);
                            const topupData = {
                              operatorId: form.watch('operatorId'),
                              amount: form.watch('amount'),
                              recipientPhone: form.watch('recipientPhone'),
                              countryCode: form.watch('countryCode'),
                              operatorName: selectedOperator?.name || 'Unknown',
                              paypalOrderId: details.id
                            };
                            sendTopupMutation.mutate(topupData);
                          }}
                          onError={(error: any) => {
                            console.error('PayPal payment error:', error);
                            toast({
                              title: "Payment Error",
                              description: "There was an issue with PayPal payment. Please try again.",
                              variant: 'destructive',
                            });
                          }}
                          onCancel={(data: any) => {
                            console.log('PayPal payment cancelled:', data);
                            toast({
                              title: "Payment Cancelled",
                              description: "PayPal payment was cancelled.",
                            });
                          }}
                        />
                      </div>
                    </div>
                  </div>
                </CardContent>
              </Card>
            )}
          </form>
        </Form>
      </main>
    </div>
  );
}
